"""
Decoder and encoder sdk descriptor
"""

from typing import Tuple


def sdkDescriptorEncode(descriptorVersion: int, descriptor: bytes, prefix: bytes = b"dp\x00\x00") -> bytes:
    """
    Encode descriptor in a SDK format.

    Args:
        descriptorVersion: descriptor version
        descriptor: descriptor vector
        prefix: descriptor prefix

    Returns:
        descriptor in the SDK format
    """
    version = descriptorVersion.to_bytes(4, byteorder="little", signed=True)
    binaryDescriptor = prefix + version + descriptor
    return binaryDescriptor


def sdkDescriptorDecode(sdkDescriptor: bytes) -> Tuple[int, bytes]:
    """
    Decode descriptor from a SDK format.

    Args:
        sdkDescriptor: SDK descriptor bytes

    Returns:
        descriptor version and descriptor vector
    Raises:
        ValueError: if length of an input bytes is less than 8
    """
    # head = sdkFormatDescriptor[:4]
    if len(sdkDescriptor) < 8:
        raise ValueError(f"bad length sdk descriptor length: {len(sdkDescriptor)}")
    descriptorVersion = int.from_bytes(sdkDescriptor[4:8], byteorder="little", signed=True)
    descriptor = sdkDescriptor[8:]
    return descriptorVersion, descriptor
